%make output vector, store in global airod.ovec
function NewAirod = AIROmkovec(OldAirod)

%define full-scale d/a output
%5V for Brad's machine, 10V for Andy's
fs = 10;

%define integer corresponding to a five-volt output
switch fs
case 5
   FiveVolts = 32752;
case 10
   FiveVolts = 16384;
end

%define scale factor from dap integers to
%analog voltages
m = 32768/fs;

%Strip ovec field initially so that its size
%is defined correctly each time, independent
%of the number of cycles.
NewAirod = rmfield(OldAirod,'ovec');

inc = NewAirod.h1*(m)/(round(NewAirod.i1/NewAirod.our)-1);

inc2 = ((NewAirod.h2-NewAirod.h1)*(m))/(round(NewAirod.i2/NewAirod.our));

inc3 = -NewAirod.h2*(m)/(round(NewAirod.i3/NewAirod.our));

ovec = [0:inc:((NewAirod.h1*(m))-inc) ...
(NewAirod.h1*(m)):inc2:((NewAirod.h2*(m))-inc2) ...
(NewAirod.h2*(m)):inc3:0];

%force values to be integral multiples of 16
ovec = 16 * round(ovec ./ 16);

%Make 1,2, or 3 copies of drive waveform
%and pad the array to 1000,2000, or 3000 values
%Make trigger vector and interlace drive & trigger.
vecsize = size(ovec,2);
switch get(findobj('Tag','numcycles'),'Value')
  case 1 %1 cycle
    ovec = [ovec zeros(1,1000-vecsize)];
    trigvec = [FiveVolts*ones(1,999) 0];
    NewAirod.ovec(1:2:1999) = trigvec;
    NewAirod.ovec(2:2:2000) = ovec;

  case 2 %2 cycles
    ovec = [ovec ovec zeros(1,2*(1000-vecsize))];
    trigvec = [FiveVolts*ones(1,1999) 0];
    NewAirod.ovec(1:2:3999) = trigvec;
    NewAirod.ovec(2:2:4000) = ovec;

  case 3 %3 cycles; triple the length
    ovec = [ovec ovec ovec zeros(1,3*(1000-vecsize))];
    trigvec = [FiveVolts*ones(1,2999) 0];
    NewAirod.ovec(1:2:5999) = trigvec;
    NewAirod.ovec(2:2:6000) = ovec;

end



