#include <stdio.h>
#include <sys/times.h>
#include <sys/types.h>
#include <sys/file.h>
#include <errno.h>
#include "mex.h"
#include "intrfc.h"
#include "dapio.c"

void mexFunction(
   int nlhs, mxArray *plhs[],
   int nrhs, const mxArray *prhs[])
   {
   double *InData;            /* data comes in from matlab */
   short OutData[1000];        /* and goes out to board */
   short DapBuf[1000];
   int i;
   clock_t t;
   struct tms buf;
   
   /* Redirect ctrl-c so that MEX file can close DAP channels
      before exiting. */
   mysig();

   /* Open handles to DAP text and binary communication pipes */
   if ((fdDapTxt=open("/dev/accel0",O_RDWR)) <= 0)
     { printf("Error opening accel0, errno=%d\n",errno); return; }
   if ((fdDapBin=open("/dev/accel1",O_RDWR)) <= 0)
     { printf("Error opening accel1, errno=%d\n",errno); return; }

   /* Send dap configuration file */
   DAPSendFile(fdDapTxt,"/home/andrew/matlab/airo/airo3.dap");

   /* Pause 200ms while file is sent to DAP */
   t = times(&buf);
   while ((times(&buf)-t) < 20) {}

   /* get pointer to input data */
   InData = mxGetPr(prhs[0]);

   /* copy dap data into output matrix, converting to type short */
   for (i=0; i < 1000; i++) {
   OutData[i] = (short) InData[i];}

   /* write to dap board via binary channel */
   write(fdDapBin,OutData,2000);

   /* copy dap data into output matrix, converting to type short */
   for (i=1000; i < 2000; i++) {
     OutData[i-1000] = (short) InData[i];}

   /* write to dap board via binary channel */
   write(fdDapBin,OutData,2000);

   /* copy and write some more */
   for (i=2000; i < 3000; i++) {
     OutData[i-2000] = (short) InData[i];}
   write(fdDapBin,OutData,2000);
   for (i=3000; i < 4000; i++) {
     OutData[i-3000] = (short) InData[i];}
   write(fdDapBin,OutData,2000);
   for (i=4000; i < 5000; i++) {
     OutData[i-4000] = (short) InData[i];}
   write(fdDapBin,OutData,2000);
   for (i=5000; i < 6000; i++) {
     OutData[i-5000] = (short) InData[i];}
   write(fdDapBin,OutData,2000);

   /* Pause 100ms while data is sent to DAP */
   t = times(&buf);
   while ((times(&buf)-t) < 10) {}

   /* Data-collecting code */

   /* create matrix to hold data */
   plhs[0] = mxCreateDoubleMatrix(1,3000,mxREAL);

   InData = mxGetPr(plhs[0]);

   /* Wait for data and get it */
   t = times(&buf);
   while (DAPGetAvail(fdDapBin) < 2000){
     if ((times(&buf)-t) > 2000) {break;}}

   if (DAPGetAvail(fdDapBin)>=2000){
     read(fdDapBin,DapBuf,2000);}

   for (i=0; i < 1000; i++){
     InData[i] = (double) DapBuf[i];}

   t = times(&buf);
   while (DAPGetAvail(fdDapBin) < 2000){
     if ((times(&buf)-t) > 2000) {break;}}

   if (DAPGetAvail(fdDapBin)>=2000){
     read(fdDapBin,DapBuf,2000);}

   for (i=1000; i < 2000; i++){
     InData[i] = (double) DapBuf[i-1000];}

   t = times(&buf);
   while (DAPGetAvail(fdDapBin) < 2000){
     if ((times(&buf)-t) > 2000) {break;}}

   if (DAPGetAvail(fdDapBin)>=2000){
     read(fdDapBin,DapBuf,2000);}

   for (i=2000; i < 3000; i++){
     InData[i] = (double) DapBuf[i-2000];}


   /* close handles */
   close(fdDapTxt);
   close(fdDapBin);

   }








